@@ -72,6 +72,8 @@ class Pbox(object):
 
         return f'Pbox: ~{shape_text}(range={range_text}, mean={mean_text}, var={var_text})'
 
+    __str__ = __repr__
+
     def __iter__(self):
         for val in np.array([self.left,self.right]).flatten():
             yield val
@@ -403,11 +405,11 @@ class Pbox(object):
             )
 
     def add(self, other, method = 'f'):
-
+       
         if method not in ['f','p','o','i']:
             raise ArithmeticError("Calculation method unkown")
 
-        if other.__class__.__name__ == 'Interval':
+        if other.__class__.__name__ == 'Interval': 
             other = Pbox(other, steps = self.steps)
 
         if other.__class__.__name__ == 'Pbox':
@@ -617,7 +619,7 @@ class Pbox(object):
         else:
             return plt
 
-        plot = show
+    plot = show
 
     def get_interval(self, *args):
 
@@ -672,6 +674,13 @@ class Pbox(object):
 
         return Interval(lb,ub)
 
+    def exp(self):
+        pass
+
+    def mean(self):
+        # check
+        return Interval(self.mean_left,self.mean_right)
+
     def support(self):
         return Interval(min(self.left),max(self.right))
 
@@ -761,6 +770,38 @@ class Pbox(object):
         s2 = s2 - mu**2
         return Pbox(u,d, mean_left=mu.left(), mean_right=mu.right(), var_left=s2.left(), var_right=s2.right())
 
+
+    def straddles(self,N, endpoints = True):
+        """
+        Parameters
+        ----------
+        N : numeric
+            Number to check
+        endpoints : bool
+            Whether to include the endpoints within the check
+
+        Returns
+        -------
+        True
+            If :math:`\\mathrm{left} \\leq N \\leq \mathrm{right}` (Assuming `endpoints=True`)
+        False
+            Otherwise
+        """
+        if endpoints:
+            if min(self.left) <= N and max(self.right) >= N:
+                return True
+        else:
+            if min(self.left) < N and max(self.right) > N:
+                return True
+
+        return False
+
+    def straddles_zero(self,endpoints = True):
+        """
+        Checks whether :math:`0` is within the p-box
+        """
+        return self.straddles(0,endpoints)
+
 # Functions
 def env_int(*args):
     left = min([min(i) if is_iterable(i) else i for i in args])
